@@ -7,11 +7,14 @@ import pandas as pd
 from Bio import SeqIO
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
-from extract_UTR import utr
-from extract_uORF import get_uorf
-from extract_dORF import get_dorf
-from extract_CDS import get_cds
-from extract_promoter import get_promoter
+from featurExtract.extract_UTR import utr
+from featurExtract.extract_uORF import get_uorf
+from featurExtract.extract_dORF import get_dorf
+from featurExtract.extract_CDS import get_cds
+from featurExtract.extract_promoter import get_promoter
+from featurExtract.extract_exon import get_exon
+from featurExtract.extract_intron import get_intron
+
 
 def create(args):
     '''
@@ -44,9 +47,9 @@ def UTR(args):
     '''
     db = gffutils.FeatureDB('gff.db', keep_order=True)
     if args.transcript:
-        utr(db, args.genome, args.transcript, args.output)
+        utr(args, db, args.genome, args.transcript, args.output)
     else:
-        utr(db, args.genome, None, args.output)
+        utr(args, db, args.genome, None, args.output)
 
 
 def uORF(args):
@@ -90,9 +93,23 @@ def exon(args):
     parameters:
      args: arguments from argparse
     '''
-    # parse arguments
-    tr_id = args.transcript
-    pass 
+    db = gffutils.FeatureDB('gff.db', keep_order=True)
+    if args.transcript:
+        get_exon(args, db, args.genome, args.transcript, args.output)
+    else:
+        get_exon(args, db, args.genome, None, args.output)
+
+def intron(args):
+    '''
+    parameters:
+     args: arguments from argparse
+    '''
+    genomeDict = genome_dict(args.genome)
+    db = gffutils.FeatureDB('gff.db', keep_order=True)
+    if args.transcript:
+        get_intron(args, db, args.genome, genomeDict, args.transcript, args.output)
+    else:
+        get_intron(args, db, args.genome, genomeDict, None, args.output)
 
 
 def promoter(args):
@@ -121,7 +138,7 @@ parser_promoter.add_argument('-l', '--length', type=int, help='promoter length b
 parser_promoter.add_argument('-u', '--utr_head', type=int, help='utr5 length after TSS')
 parser_promoter.add_argument('-f', '--genome', type=str, help='genome fasta')
 parser_promoter.add_argument('-o', '--output', type=str, help = 'output csv file path')
-parser_promoter.add_argument('-p', '--print', action="store_true", help='stdin')
+parser_promoter.add_argument('-p', '--print', action="store_true", help='boolean type, stdin')
 parser_promoter.add_argument('-v', '--version', help = 'promoterExtract version', action = "store_true")
 parser_promoter.set_defaults(func=promoter)
 
@@ -131,6 +148,7 @@ parser_utr.add_argument('-f', '--genome', type=str, help='genome fasta file')
 parser_utr.add_argument('-t', '--transcript', type=str, help='specific transcript id; if not given, \
                        whole transcript will return')
 parser_utr.add_argument('-o', '--output', type=str, help='output file path')
+parser_utr.add_argument('-p', '--print', action="store_true", help='boolean type, stdout')
 parser_utr.set_defaults(func=UTR)
 
 # uORF subcommand
@@ -143,11 +161,12 @@ parser_uORF.set_defaults(func=uORF)
 
 # CDS subcommand
 parser_cds = subparsers.add_parser('CDS', help='extract coding sequence in genome or gene')
+parser_cds.add_argument('-c', '--csv', action="store_true", help='output file format')
 parser_cds.add_argument('-f', '--genome', type=str, help='genome fasta')
 parser_cds.add_argument('-t', '--transcript', type=str, help='specific transcript id; if not given, \
                        whole transcript will return')
 parser_cds.add_argument('-o', '--output', type=str, help='output file path')
-parser_cds.add_argument('-p', '--print', action="store_true", help='stdin')
+parser_cds.add_argument('-p', '--print', action="store_true", help='boolean type; stdin')
 parser_cds.set_defaults(func=CDS)
 
 # dORF subcommand 
@@ -159,21 +178,26 @@ parser_dORF.add_argument('-o', '--output', type=str, help='output file path')
 parser_dORF.add_argument('-p', '--print', action="store_true", help='stdin')
 parser_dORF.set_defaults(func=dORF)
 
+
+# exon 
+parser_exon = subparsers.add_parser('exon', help='extract exon sequence for a given transcript')
+parser_exon.add_argument('-f', '--genome', type=str, help='genome fasta')
+parser_exon.add_argument('-t', '--transcript', type=str, help='specific transcript id; needed')
+parser_exon.add_argument('-o', '--output', type=str, help='output file path')
+parser_exon.add_argument('-p', '--print', action="store_true", help='stdin')
+parser_exon.set_defaults(func=exon)
+
+# intron 
+parser_intron = subparsers.add_parser('intron', help='extract exon sequence for a given transcript')
+parser_intron.add_argument('-f', '--genome', type=str, help='genome fasta')
+parser_intron.add_argument('-t', '--transcript', type=str, help='specific transcript id; needed')
+parser_intron.add_argument('-o', '--output', type=str, help='output file path')
+parser_intron.add_argument('-p', '--print', action="store_true", help='stdin')
+parser_intron.set_defaults(func=intron)
+
+
 args = parser.parse_args()
 print('[%s runing ...]'%(time.strftime("%a %b %d %H:%M:%S %Y", time.localtime())))
 args.func(args)
 print('[%s finished ...]'%(time.strftime("%a %b %d %H:%M:%S %Y", time.localtime())))
 
-
-
-'''
-if __name__ == '__main__':
-    parser = argparse.ArgumentParser()
-    parser.add_argument('-l', '--length', type=int, help='promoter length before TSS')
-    parser.add_argument('-u', '--utr_head', type=int, help='length after TSS')
-    parser.add_argument('-f', '--genome', type=str, help='genome fasta')
-    parser.add_argument('-g', '--gff', type=str, help='genome annotation file')
-    parser.add_argument('-o', '--outdir', type=str, help='output directory')
-    args = parser.parse_args()
-    get_promoter(args.length, args.utr_head, args.genome, args.gff, args.outdir)
-'''                                             
